# AnnotationTypeEnum 枚举

## 概述

`AnnotationTypeEnum` 枚举是所有注释种类枚举类的基类。内部无枚举值，只用于被继承。

模块：[pymaidol.AnnotationType](AnnotationType模块.md)

继承自：`enum.Enum`

## 导入

```python
from pymaidol import AnnotationTypeEnum
```

或

```python
from pymaidol.AnnotationType import AnnotationTypeEnum
```
